aboutsummaryrefslogtreecommitdiffstats
path: root/host/lib/usrp/usrp_e/usrp_e_impl.hpp
diff options
context:
space:
mode:
authorJosh Blum <josh@joshknows.com>2010-04-16 12:58:42 +0000
committerJosh Blum <josh@joshknows.com>2010-04-16 12:58:42 +0000
commit839d9c39542db356ad1b955e3a3d9e7aabb071bc (patch)
tree0bb8a08c6d7e046a4a2199fb73a56264bc10f7ec /host/lib/usrp/usrp_e/usrp_e_impl.hpp
parent835cb56ef820a69e1e6e0ccde7c5a0e78ca5ad25 (diff)
downloaduhd-839d9c39542db356ad1b955e3a3d9e7aabb071bc.tar.gz
uhd-839d9c39542db356ad1b955e3a3d9e7aabb071bc.tar.bz2
uhd-839d9c39542db356ad1b955e3a3d9e7aabb071bc.zip
pulled in master and got usrp-e code compiling
Diffstat (limited to 'host/lib/usrp/usrp_e/usrp_e_impl.hpp')
-rw-r--r--host/lib/usrp/usrp_e/usrp_e_impl.hpp26
1 files changed, 6 insertions, 20 deletions
diff --git a/host/lib/usrp/usrp_e/usrp_e_impl.hpp b/host/lib/usrp/usrp_e/usrp_e_impl.hpp
index 21023ae55..08ace2ffb 100644
--- a/host/lib/usrp/usrp_e/usrp_e_impl.hpp
+++ b/host/lib/usrp/usrp_e/usrp_e_impl.hpp
@@ -15,21 +15,20 @@
// along with this program. If not, see <http://www.gnu.org/licenses/>.
//
-#include <uhd/types/clock_config.hpp>
+#include "usrp_e_iface.hpp"
#include <uhd/usrp/usrp_e.hpp>
+#include <uhd/types/clock_config.hpp>
#include <uhd/usrp/dboard_manager.hpp>
#ifndef INCLUDED_USRP_E_IMPL_HPP
#define INCLUDED_USRP_E_IMPL_HPP
-class usrp_e_impl; // dummy class declaration
-
/*!
* Make a usrp_e dboard interface.
* \param impl a pointer to the usrp_e impl object
* \return a sptr to a new dboard interface
*/
-uhd::usrp::dboard_interface::sptr make_usrp_e_dboard_interface(usrp_e_impl *impl);
+uhd::usrp::dboard_iface::sptr make_usrp_e_dboard_iface(usrp_e_iface::sptr iface);
/*!
* Simple wax obj proxy class:
@@ -84,22 +83,9 @@ public:
size_t send(const boost::asio::const_buffer &, const uhd::tx_metadata_t &, const uhd::io_type_t &);
size_t recv(const boost::asio::mutable_buffer &, uhd::rx_metadata_t &, const uhd::io_type_t &);
- /*!
- * Perform an ioctl call on the device node file descriptor.
- * This will throw when the internal ioctl call fails.
- * \param request the control word
- * \param mem pointer to some memory
- */
- void ioctl(int request, void *mem);
-
- //peekers and pokers
- void poke32(boost::uint32_t addr, boost::uint32_t value);
- void poke16(boost::uint32_t addr, boost::uint16_t value);
- boost::uint32_t peek32(boost::uint32_t addr);
- boost::uint16_t peek16(boost::uint32_t addr);
-
private:
static const size_t _max_num_samples = 2048/sizeof(boost::uint32_t);
+ usrp_e_iface::sptr _iface;
int _node_fd;
uhd::clock_config_t _clock_config;
@@ -15,21 +15,20 @@
/*!
- * Make a usrp_e dboard interface.
- * \param impl a pointer to the usrp_e impl object
+ * Make a usrp-e dboard interface.
+ * \param iface the usrp-e interface object
* \return a sptr to a new dboard interface
*/